@@ -1,36 +1,30 @@
-import base64
 import subprocess
 import time
 import json
 import re
-import os
-import hashlib
 import logging
 import datetime
 from types import NoneType
-from typing import Callable
 from collections import namedtuple
 from uuid import UUID, uuid4
 
-import humanize
 import requests
-from cassandra.util import uuid_from_time
+from cassandra.util import uuid_from_time  # pylint: disable=no-name-in-module
 from cassandra.cqlengine import ValidationError
-from flask import g, current_app, session
-from werkzeug.security import check_password_hash, generate_password_hash
+from flask import g, current_app
 from argus.backend.db import ScyllaCluster
+from argus.backend.plugins.sct.testrun import SCTTestRun
 from argus.backend.service.notification_manager import NotificationManagerService
-from argus.db.db_types import TestInvestigationStatus
-from argus.db.testrun import TestRun, TestStatus
-from argus.db.models import (
+from argus.backend.util.enums import TestStatus, TestInvestigationStatus
+from argus.backend.models.web import (
     ArgusGithubIssue,
     ArgusRelease,
-    ArgusReleaseGroup,
-    ArgusReleaseGroupTest,
-    ArgusReleaseSchedule,
-    ArgusReleaseScheduleAssignee,
-    ArgusReleaseScheduleGroup,
-    ArgusReleaseScheduleTest,
+    ArgusGroup,
+    ArgusTest,
+    ArgusSchedule,
+    ArgusScheduleAssignee,
+    ArgusScheduleGroup,
+    ArgusScheduleTest,
     ArgusTestRunComment,
     ArgusNotificationSourceTypes,
     ArgusNotificationTypes,
@@ -38,41 +32,13 @@ from argus.db.models import (
     ArgusEventTypes,
     ReleasePlannerComment,
     User,
-    UserOauthToken,
-    WebFileStorage,
 )
-from argus.backend.event_processors import EVENT_PROCESSORS
+from argus.backend.events.event_processors import EVENT_PROCESSORS
+from argus.backend.util.common import strip_html_tags
 
 LOGGER = logging.getLogger(__name__)
 
 
-def first(iterable, value, key: Callable = None, predicate: Callable = None):
-    for elem in iterable:
-        if predicate and predicate(elem, value):
-            return elem
-        elif key and key(elem) == value:
-            return elem
-        elif elem == value:
-            return elem
-    return None
-
-
-def check_scheduled_test(test, group, testname):
-    return testname == f"{group}/{test}" or testname == test
-
-
-def strip_html_tags(text: str):
-    return text.replace("<", "&lt;").replace(">", "&gt;")
-
-
-def convert_str_list_to_uuid(l: list[str]) -> list[UUID]:
-    return [UUID(s) for s in l]
-
-
-class GithubOrganizationMissingError(Exception):
-    pass
-
-
 class ArgusService:
     # pylint: disable=no-self-use,too-many-arguments,too-many-instance-attributes,too-many-locals, too-many-public-methods
     def __init__(self, database_session=None):
@@ -83,55 +49,16 @@ class ArgusService:
             "Accept": "application/vnd.github.v3+json",
             "Authorization": f"token {current_app.config['GITHUB_ACCESS_TOKEN']}"
         }
-        self.runs_by_id_stmt = self.database.prepare(
-            f"SELECT * FROM {TestRun.table_name()} WHERE id = ?"
-        )
-        self.run_by_release_name_stmt = self.database.prepare(
-            "SELECT id, test_id, group_id, release_id, build_job_url, build_id, "
-            "status, start_time, end_time, heartbeat "
-            f"FROM {TestRun.table_name()} WHERE release_id = ?"
-        )
-        self.runs_by_build_system_id = self.database.prepare(
-            "SELECT id, test_id, group_id, release_id, build_job_url, build_id, "
-            "status, start_time, end_time, heartbeat "
-            f"FROM {TestRun.table_name()} WHERE build_id = ? LIMIT ?"
-        )
-        self.jobs_by_assignee = self.database.prepare(
-            "SELECT id, status, start_time, assignee, release_id, "
-            "investigation_status, "
-            "group_id, test_id, build_job_url, build_id FROM "
-            f"{TestRun.table_name()} WHERE assignee = ?"
-        )
-        self.run_by_release_stats_statement = self.database.prepare(
-            "SELECT id, test_id, group_id, release_id, status, start_time, build_job_url, build_id, assignee, "
-            f"end_time, investigation_status, heartbeat FROM {TestRun.table_name()} WHERE release_id = ?"
-        )
-        self.stats_by_build_id_statement = self.database.prepare(
-            "SELECT id, test_id, group_id, release_id, status, start_time, build_job_url, build_id, assignee, "
-            f"end_time, investigation_status, heartbeat FROM {TestRun.table_name()} WHERE build_id IN ?"
-        )
         self.build_id_and_url_statement = self.database.prepare(
-            f"SELECT build_id, build_job_url, test_id FROM {TestRun.table_name()} WHERE id = ?"
+            f"SELECT build_id, build_job_url, test_id FROM {SCTTestRun.table_name()} WHERE id = ?"
         )
         self.event_insert_statement = self.database.prepare(
             'INSERT INTO argus.argus_event '
             '("id", "release_id", "group_id", "test_id", "run_id", "user_id", "kind", "body", "created_at") '
             'VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)'
         )
-        self.assignee_runs_by_schedule = self.database.prepare(
-            f"SELECT build_id, start_time, assignee, test_id FROM {TestRun.table_name()} "
-            "WHERE build_id = ? AND start_time >= ? AND start_time <= ?"
-        )
-        self.assignee_runs_by_schedule_multi = self.database.prepare(
-            f"SELECT build_id, start_time, assignee, test_id FROM {TestRun.table_name()} "
-            "WHERE build_id IN ? AND start_time >= ? AND start_time <= ?"
-        )
-        self.assignee_update_stmt = self.database.prepare(
-            f"UPDATE {TestRun.table_name()} SET assignee = ?"
-            "WHERE build_id = ? AND start_time = ?"
-        )
         self.scylla_versions_by_release = self.database.prepare(
-            f"SELECT scylla_version FROM {TestRun.table_name()} WHERE release_id = ?"
+            f"SELECT scylla_version FROM {SCTTestRun.table_name()} WHERE release_id = ?"
         )
 
     def get_version(self) -> str:
@@ -176,7 +103,7 @@ class ArgusService:
     def create_groups(self, groups: dict, parent_release_id) -> dict:
         response = {}
         for group_name, group_definition in groups.items():
-            new_group = ArgusReleaseGroup()
+            new_group = ArgusGroup()
             new_group.release_id = parent_release_id
             new_group.name = group_name
             new_group.pretty_name = group_definition.get("pretty_name")
@@ -194,7 +121,7 @@ class ArgusService:
         response = {}
 
         for test_name in tests:
-            new_test = ArgusReleaseGroupTest()
+            new_test = ArgusTest()
             new_test.release_id = parent_release_id
             new_test.group_id = parent_group_id
             new_test.name = test_name
@@ -204,8 +131,10 @@ class ArgusService:
         return response
 
     def load_test_run(self, test_run_id: UUID):
-        run = TestRun.from_id(test_id=test_run_id)
-        return run.serialize() if run else None
+        try:
+            return SCTTestRun.get(id=test_run_id)
+        except SCTTestRun.DoesNotExist:
+            return None
 
     def get_comment(self, comment_id: UUID) -> ArgusTestRunComment | None:
         try:
@@ -216,10 +145,6 @@ class ArgusService:
     def get_comments(self, test_id: UUID) -> list[ArgusTestRunComment]:
         return sorted(ArgusTestRunComment.filter(test_run_id=test_id).all(), key=lambda c: c.posted_at)
 
-    def get_user_info(self) -> dict:
-        users = User.all()
-        return {str(user.id): user.to_json() for user in users}
-
     def post_comment(self, payload: dict) -> list[ArgusTestRunComment]:
         test_run_id: str = payload.get("test_run_id")
         if not test_run_id:
@@ -269,7 +194,8 @@ class ArgusService:
                 notification_type=ArgusNotificationTypes.Mention,
                 source_type=ArgusNotificationSourceTypes.Comment,
                 source_id=comment.id,
-                content_params=params
+                content_params=params,
+                source_message=comment.message,
             )
 
         self.send_event(kind=ArgusEventTypes.TestRunCommentPosted, body={
@@ -346,20 +272,20 @@ class ArgusService:
         releases = sorted(releases, key=lambda r: r.dormant)
         return releases
 
-    def get_groups(self, release_id: UUID) -> list[ArgusReleaseGroup]:
-        groups = list(ArgusReleaseGroup.filter(release_id=release_id).all())
+    def get_groups(self, release_id: UUID) -> list[ArgusGroup]:
+        groups = list(ArgusGroup.filter(release_id=release_id).all())
         return sorted(groups, key=lambda g: g.pretty_name if g.pretty_name else g.name)
 
     def get_groups_for_release(self, release: ArgusRelease):
-        groups = ArgusReleaseGroup.filter(release_id=release.id).all()
+        groups = ArgusGroup.filter(release_id=release.id).all()
         return sorted(groups, key=lambda g: g.pretty_name if g.pretty_name else g.name)
 
-    def get_tests(self, group_id: UUID) -> list[ArgusReleaseGroupTest]:
-        return list(ArgusReleaseGroupTest.filter(group_id=group_id).all())
+    def get_tests(self, group_id: UUID) -> list[ArgusTest]:
+        return list(ArgusTest.filter(group_id=group_id).all())
 
     def get_test_info(self, test_id: UUID) -> dict:
-        test = ArgusReleaseGroupTest.get(id=test_id)
-        group = ArgusReleaseGroup.get(id=test.group_id)
+        test = ArgusTest.get(id=test_id)
+        group = ArgusGroup.get(id=test.group_id)
         release = ArgusRelease.get(id=test.release_id)
         return {
             "test": dict(test.items()),
@@ -369,8 +295,8 @@ class ArgusService:
 
     def get_data_for_release_dashboard(self, release_name: str):
         release = ArgusRelease.get(name=release_name)
-        release_groups = ArgusReleaseGroup.filter(release_id=release.id).all()
-        release_tests = ArgusReleaseGroupTest.filter(release_id=release.id).all()
+        release_groups = ArgusGroup.filter(release_id=release.id).all()
+        release_tests = ArgusTest.filter(release_id=release.id).all()
 
         return release, release_groups, release_tests
 
@@ -382,44 +308,35 @@ class ArgusService:
         return sorted(list(unique_versions), reverse=True)
 
     def poll_test_runs(self, test_id: UUID, additional_runs: list[UUID], limit: int = 10):
-        test: ArgusReleaseGroupTest = ArgusReleaseGroupTest.get(id=test_id)
+        test: ArgusTest = ArgusTest.get(id=test_id)
 
-        rows = self.session.execute(
-            self.runs_by_build_system_id,
-            parameters=(test.build_system_id, limit),
-            execution_profile="read_fast"
-        ).all()
+        rows: list[SCTTestRun] = list(SCTTestRun.filter(build_id=test.build_system_id).all().limit(limit))
 
-        rows_ids = [row["id"] for row in rows]
+        rows_ids = [row.id for row in rows]
 
         for run_id in additional_runs:
             if run_id not in rows_ids:
-                row = self.session.execute(
-                    self.runs_by_id_stmt,
-                    parameters=(UUID(run_id),),
-                    execution_profile="read_fast"
-                ).one()
+                row: SCTTestRun = SCTTestRun.get(id=run_id)
                 rows.append(row)
 
         for row in rows:
             try:
-                row["build_number"] = int(
-                    row["build_job_url"].rstrip("/").split("/")[-1])
+                setattr(row, "build_number", int(row["build_job_url"].rstrip("/").split("/")[-1]))
             except ValueError:
-                row["build_number"] = -1
+                setattr(row, "build_number", -1)
 
         return rows
 
     def poll_test_runs_single(self, runs: list[UUID]):
-        rows = []
+        rows: list[SCTTestRun] = []
         for run_id in runs:
-            row = self.session.execute(self.runs_by_id_stmt, parameters=(
-                run_id,), execution_profile="read_fast_named_tuple").one()
-            rows.append(row)
-
-        response = {str(row.id): TestRun.from_db_row(row).serialize()
-                    for row in rows if row}
+            try:
+                row: SCTTestRun = SCTTestRun.get(id=run_id)
+                rows.append(row)
+            except SCTTestRun.DoesNotExist:
+                pass
 
+        response = {str(row.id): row for row in rows}
         return response
 
     def send_event(self, kind: str, body: dict, user_id=None, run_id=None, release_id=None, group_id=None, test_id=None):
@@ -445,10 +362,10 @@ class ArgusService:
             raise Exception("New Status wasn't specified in the request")
 
         new_status = TestStatus(new_status)
-        test_run = TestRun.from_id(test_id=UUID(test_run_id))
-        test = ArgusReleaseGroupTest.get(build_system_id=test_run.build_id)
-        old_status = test_run.run_info.results.status
-        test_run.run_info.results.status = new_status
+        test_run: SCTTestRun = SCTTestRun.get(id=UUID(test_run_id))
+        test = ArgusTest.get(build_system_id=test_run.build_id)
+        old_status = TestStatus(test_run.status)
+        test_run.status = new_status.value
         test_run.save()
 
         self.send_event(
@@ -479,10 +396,10 @@ class ArgusService:
             raise Exception("New investigation status wasn't specified in the request")
 
         new_status = TestInvestigationStatus(new_status)
-        test_run = TestRun.from_id(UUID(test_run_id))
-        test = ArgusReleaseGroupTest.get(build_system_id=test_run.build_id)
+        test_run: SCTTestRun = SCTTestRun.get(id=UUID(test_run_id))
+        test = ArgusTest.get(build_system_id=test_run.build_id)
         old_status = test_run.investigation_status
-        test_run.investigation_status = new_status
+        test_run.investigation_status = new_status.value
         test_run.save()
 
         self.send_event(
@@ -519,8 +436,8 @@ class ArgusService:
             if new_assignee != "none-none-none":
                 raise
             new_assignee = DummyUser(id=None, username="None")
-        test_run = TestRun.from_id(test_id=UUID(test_run_id))
-        test = ArgusReleaseGroupTest.get(build_system_id=test_run.build_id)
+        test_run: SCTTestRun = SCTTestRun.get(id=UUID(test_run_id))
+        test = ArgusTest.get(build_system_id=test_run.build_id)
         old_assignee = test_run.assignee
         old_assignee = User.get(id=old_assignee) if old_assignee else None
         test_run.assignee = new_assignee.id
@@ -588,10 +505,10 @@ class ArgusService:
         if not match:
             raise Exception("URL doesn't match Github schema")
 
-        run = self.session.execute(self.runs_by_id_stmt, parameters=(UUID(run_id),)).one()
+        run = SCTTestRun.get(id=UUID(run_id))
         release = ArgusRelease.get(id=run["release_id"])
-        test = ArgusReleaseGroupTest.get(build_system_id=run["build_id"])
-        group = ArgusReleaseGroup.get(id=test.group_id)
+        test = ArgusTest.get(build_system_id=run["build_id"])
+        group = ArgusGroup.get(id=test.group_id)
 
         new_issue = ArgusGithubIssue()
         new_issue.user_id = g.user.id
@@ -690,66 +607,32 @@ class ArgusService:
             "deleted": issue_id
         }
 
-    def fetch_release_issues(self, payload: dict) -> dict:
-        # TODO: Unused
-        """
-        Example payload
-        {
-            "release_id": "abcadedf-efadd-24124",
-            "tests": [ArgusReleaseGroupTest <, ...>]
-        }
-        Response
-        [[ArgusReleaseGroupTest, GithubIssue[]], ...]
-        """
-
-        release_id = payload.get("release_id")
-        if not release_id:
-            raise Exception("ReleaseId wasn't specified in the request")
-
-        release_issues = self.get_github_issues({
-            "filter_key": "release_id",
-            "id": release_id
-        })
-
-        tests = payload.get("tests", [])
-
-        response = []
-        for test in tests:
-            issues_for_test = [issue for issue in release_issues if issue["test_id"] == UUID(test["id"])]
-            if len(issues_for_test) > 0:
-                response.append([test, issues_for_test])
-
-        return response
-
-    def assign_runs_for_scheduled_test(self, schedule: ArgusReleaseSchedule, test_id: UUID, new_assignee: UUID):
-        test = ArgusReleaseGroupTest.get(id=test_id)
-        affected_rows = self.session.execute(
-            self.assignee_runs_by_schedule,
-            parameters=(test.build_system_id, schedule.period_start, schedule.period_end)
+    def assign_runs_for_scheduled_test(self, schedule: ArgusSchedule, test_id: UUID, new_assignee: UUID):
+        test: ArgusTest = ArgusTest.get(id=test_id)
+        affected_rows: list[SCTTestRun] = list(SCTTestRun.filter(
+            build_id=test.build_system_id,
+            start_time__gte=schedule.period_start,
+            start_time__lte=schedule.period_end
+        ).all()
         )
-
         for row in affected_rows:
-            if row["assignee"] == new_assignee:
-                continue
-            self.session.execute(
-                self.assignee_update_stmt,
-                parameters=(new_assignee, row["build_id"], row["start_time"])
-            )
+            if row.assignee != new_assignee:
+                row.assignee = new_assignee
+                row.save()
 
-    def assign_runs_for_scheduled_group(self, schedule: ArgusReleaseSchedule, group_id: UUID, new_assignee: UUID):
-        tests = ArgusReleaseGroupTest.filter(group_id=group_id).all()
+    def assign_runs_for_scheduled_group(self, schedule: ArgusSchedule, group_id: UUID, new_assignee: UUID):
+        tests = ArgusTest.filter(group_id=group_id).all()
         build_ids = [test.build_system_id for test in tests]
-        affected_rows = self.session.execute(
-            self.assignee_runs_by_schedule_multi,
-            parameters=(build_ids, schedule.period_start, schedule.period_end)
+        affected_rows: list[SCTTestRun] = list(SCTTestRun.filter(
+            build_id__in=build_ids,
+            start_time__gte=schedule.period_start,
+            start_time__lte=schedule.period_end
+        ).all()
         )
         for row in affected_rows:
-            if row["assignee"] == new_assignee:
-                continue
-            self.session.execute(
-                self.assignee_update_stmt,
-                parameters=(new_assignee, row["build_id"], row["start_time"])
-            )
+            if row.assignee != new_assignee:
+                row.assignee = new_assignee
+                row.save()
 
     def submit_new_schedule(self, release: str | UUID, start_time: str, end_time: str, tests: list[str | UUID],
                             groups: list[str | UUID], assignees: list[str | UUID], tag: str) -> dict:
@@ -760,7 +643,7 @@ class ArgusService:
         if len(tests) == 0 and len(groups) == 0:
             raise Exception("Schedule does not contain scheduled objects")
 
-        schedule = ArgusReleaseSchedule()
+        schedule = ArgusSchedule()
         schedule.release_id = release
         schedule.period_start = datetime.datetime.fromisoformat(start_time)
         schedule.period_end = datetime.datetime.fromisoformat(end_time)
@@ -774,7 +657,7 @@ class ArgusService:
         response["groups"] = []
 
         for test_id in tests:
-            test_entity = ArgusReleaseScheduleTest()
+            test_entity = ArgusScheduleTest()
             test_entity.id = uuid_from_time(schedule.period_start)
             test_entity.schedule_id = schedule.id
             test_entity.test_id = UUID(test_id) if isinstance(test_id, str) else test_id
@@ -784,7 +667,7 @@ class ArgusService:
             response["tests"].append(test_id)
 
         for group_id in groups:
-            group_entity = ArgusReleaseScheduleGroup()
+            group_entity = ArgusScheduleGroup()
             group_entity.id = uuid_from_time(schedule.period_start)
             group_entity.schedule_id = schedule.id
             group_entity.group_id = UUID(group_id) if isinstance(group_id, str) else group_id
@@ -794,7 +677,7 @@ class ArgusService:
             response["groups"].append(group_id)
 
         for assignee_id in assignees:
-            assignee_entity = ArgusReleaseScheduleAssignee()
+            assignee_entity = ArgusScheduleAssignee()
             assignee_entity.id = uuid_from_time(schedule.period_start)
             assignee_entity.schedule_id = schedule.id
             assignee_entity.assignee = UUID(assignee_id) if isinstance(assignee_id, str) else assignee_id
@@ -815,20 +698,20 @@ class ArgusService:
         if release.perpetual:
             today = datetime.datetime.utcnow()
             six_months_ago = today - datetime.timedelta(days=180)
-            u = uuid_from_time(six_months_ago)
-            schedules = ArgusReleaseSchedule.filter(release_id=release_id, id__gte=u).all()
+            uuid_six_months = uuid_from_time(six_months_ago)
+            schedules = ArgusSchedule.filter(release_id=release_id, id__gte=uuid_six_months).all()
         else:
-            schedules = ArgusReleaseSchedule.filter(release_id=release_id).all()
+            schedules = ArgusSchedule.filter(release_id=release_id).all()
         response = {
             "schedules": []
         }
         for schedule in schedules:
             serialized_schedule = dict(schedule.items())
-            tests = ArgusReleaseScheduleTest.filter(schedule_id=schedule.id).all()
+            tests = ArgusScheduleTest.filter(schedule_id=schedule.id).all()
             serialized_schedule["tests"] = [test.test_id for test in tests]
-            groups = ArgusReleaseScheduleGroup.filter(schedule_id=schedule.id).all()
+            groups = ArgusScheduleGroup.filter(schedule_id=schedule.id).all()
             serialized_schedule["groups"] = [group.group_id for group in groups]
-            assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule.id).all()
+            assignees = ArgusScheduleAssignee.filter(schedule_id=schedule.id).all()
             serialized_schedule["assignees"] = [assignee.assignee for assignee in assignees]
             response["schedules"].append(serialized_schedule)
 
@@ -854,18 +737,18 @@ class ArgusService:
             raise Exception("No assignees provided")
 
         release = ArgusRelease.get(id=release_id)
-        schedule = ArgusReleaseSchedule.get(release_id=release.id, id=schedule_id)
-        schedule_tests = ArgusReleaseScheduleTest.filter(schedule_id=schedule.id).all()
-        schedule_groups = ArgusReleaseScheduleGroup.filter(schedule_id=schedule.id).all()
+        schedule = ArgusSchedule.get(release_id=release.id, id=schedule_id)
+        schedule_tests = ArgusScheduleTest.filter(schedule_id=schedule.id).all()
+        schedule_groups = ArgusScheduleGroup.filter(schedule_id=schedule.id).all()
         for test in schedule_tests:
             self.assign_runs_for_scheduled_test(schedule, test.test_id, UUID(assignees[0]))
 
         for group in schedule_groups:
             self.assign_runs_for_scheduled_group(schedule, group.group_id, UUID(assignees[0]))
 
-        old_assignees = list(ArgusReleaseScheduleAssignee.filter(schedule_id=schedule.id).all())
+        old_assignees = list(ArgusScheduleAssignee.filter(schedule_id=schedule.id).all())
         for new_assignee in assignees:
-            assignee = ArgusReleaseScheduleAssignee()
+            assignee = ArgusScheduleAssignee()
             assignee.release_id = release.id
             assignee.schedule_id = schedule.id
             assignee.assignee = UUID(new_assignee)
@@ -932,10 +815,10 @@ class ArgusService:
             raise Exception("Schedule id not specified in the request")
 
         release = ArgusRelease.get(id=release_id)
-        schedule = ArgusReleaseSchedule.get(release_id=release.id, id=schedule_id)
-        tests = ArgusReleaseScheduleTest.filter(schedule_id=schedule.id).all()
-        groups = ArgusReleaseScheduleGroup.filter(schedule_id=schedule.id).all()
-        assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule.id).all()
+        schedule = ArgusSchedule.get(release_id=release.id, id=schedule_id)
+        tests = ArgusScheduleTest.filter(schedule_id=schedule.id).all()
+        groups = ArgusScheduleGroup.filter(schedule_id=schedule.id).all()
+        assignees = ArgusScheduleAssignee.filter(schedule_id=schedule.id).all()
 
         for entities in [tests, groups, assignees]:
             for entity in entities:
@@ -952,9 +835,9 @@ class ArgusService:
 
         release = ArgusRelease.get(id=release_id)
         release_comments = list(ReleasePlannerComment.filter(release=release.id).all())
-        groups = ArgusReleaseGroup.filter(release_id=release.id).all()
+        groups = ArgusGroup.filter(release_id=release.id).all()
         groups_by_group_id = {str(group.id): dict(group.items()) for group in groups if group.enabled}
-        tests = ArgusReleaseGroupTest.filter(release_id=release.id).all()
+        tests = ArgusTest.filter(release_id=release.id).all()
         tests = [dict(t.items()) for t in tests if t.enabled]
         tests_by_group = {}
         for test in tests:
@@ -985,21 +868,22 @@ class ArgusService:
         release_id = UUID(release_id) if isinstance(release_id, str) else release_id
         release = ArgusRelease.get(id=release_id)
 
-        groups = ArgusReleaseGroup.filter(release_id=release_id).all()
+        groups = ArgusGroup.filter(release_id=release_id).all()
         group_ids = [group.id for group in groups if group.enabled]
 
-        scheduled_groups = ArgusReleaseScheduleGroup.filter(release_id=release.id, group_id__in=group_ids).all()
+        scheduled_groups = ArgusScheduleGroup.filter(release_id=release.id, group_id__in=group_ids).all()
         schedule_ids = {schedule.schedule_id for schedule in scheduled_groups}
 
-        schedules = ArgusReleaseSchedule.filter(release_id=release.id, id__in=tuple(schedule_ids)).all()
+        schedules = ArgusSchedule.filter(release_id=release.id, id__in=tuple(schedule_ids)).all()
 
+        valid_schedules = schedules
         if release.perpetual:
             today = datetime.datetime.utcnow()
             valid_schedules = [s for s in schedules if s.period_start <= today <= s.period_end]
 
         response = {}
         for schedule in valid_schedules:
-            assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule.id).all()
+            assignees = ArgusScheduleAssignee.filter(schedule_id=schedule.id).all()
             assignees_uuids = [assignee.assignee for assignee in assignees]
             schedule_groups = filter(lambda g: g.schedule_id == schedule.id, scheduled_groups)
             groups = {str(group.group_id): assignees_uuids for group in schedule_groups}
@@ -1009,16 +893,17 @@ class ArgusService:
 
     def get_tests_assignees(self, group_id: UUID | str):
         group_id = UUID(group_id) if isinstance(group_id, str) else group_id
-        group = ArgusReleaseGroup.get(id=group_id)
+        group = ArgusGroup.get(id=group_id)
 
         release = ArgusRelease.get(id=group.release_id)
-        tests = ArgusReleaseGroupTest.filter(group_id=group_id).all()
+        tests = ArgusTest.filter(group_id=group_id).all()
 
         test_ids = [test.id for test in tests if test.enabled]
 
-        scheduled_tests = ArgusReleaseScheduleTest.filter(release_id=release.id, test_id__in=tuple(test_ids)).all()
+        scheduled_tests = ArgusScheduleTest.filter(release_id=release.id, test_id__in=tuple(test_ids)).all()
         schedule_ids = {test.schedule_id for test in scheduled_tests}
-        schedules = list(ArgusReleaseSchedule.filter(release_id=release.id, id__in=tuple(schedule_ids)).all())
+        schedules: list[ArgusSchedule] = list(ArgusSchedule.filter(
+            release_id=release.id, id__in=tuple(schedule_ids)).all())
 
         if release.perpetual:
             today = datetime.datetime.utcnow()
@@ -1026,7 +911,7 @@ class ArgusService:
 
         response = {}
         for schedule in schedules:
-            assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule.id).all()
+            assignees = ArgusScheduleAssignee.filter(schedule_id=schedule.id).all()
             assignees_uuids = [assignee.assignee for assignee in assignees]
             schedule_tests = filter(lambda t: t.schedule_id == schedule.id, scheduled_tests)
             tests = {str(test.test_id): assignees_uuids for test in schedule_tests}
@@ -1034,176 +919,51 @@ class ArgusService:
 
         return response
 
-    def update_email(self, user: User, new_email: str):
-        user.email = new_email
-        user.save()
-
-    def update_password(self, user: User, old_password: str, new_password: str):
-        if check_password_hash(user.password, old_password):
-            raise Exception("Incorrect old password")
-
-        user.password = generate_password_hash(new_password)
-        user.save()
-
-    def update_name(self, user: User, new_name: str):
-        user.full_name = new_name
-        user.save()
-
-    def update_profile_picture(self, filename, filepath):
-        web_file = WebFileStorage()
-        web_file.filename = filename
-        web_file.filepath = filepath
-        web_file.save()
-
-        try:
-            if old_picture_id := g.user.picture_id:
-                old_file = WebFileStorage.get(id=old_picture_id)
-                os.unlink(old_file.filepath)
-                old_file.delete()
-        except Exception as exc:  # pylint: disable=broad-except
-            print(exc)
-
-        g.user.picture_id = web_file.id
-        g.user.save()
-
-    def save_profile_picture_to_disk(self, original_filename, filedata, suffix):
-        filename_fragment = hashlib.sha256(os.urandom(64)).hexdigest()[:10]
-        filename = f"profile_{suffix}_{filename_fragment}"
-        filepath = f"storage/profile_pictures/{filename}"
-        with open(filepath, "wb") as file:
-            file.write(filedata)
-
-        return original_filename, filepath
-
-    def github_callback(self, req_code):
-        oauth_response = requests.post("https://github.com/login/oauth/access_token",
-                                       headers={
-                                           "Accept": "application/json",
-                                       },
-                                       params={
-                                           "code": req_code,
-                                           "client_id": current_app.config.get("GITHUB_CLIENT_ID"),
-                                           "client_secret": current_app.config.get("GITHUB_CLIENT_SECRET"),
-                                       })
-
-        oauth_data = oauth_response.json()
-
-        user_info = requests.get("https://api.github.com/user",
-                                 headers={
-                                     "Accept": "application/json",
-                                     "Authorization": f"token {oauth_data.get('access_token')}"
-                                 }).json()
-        email_info = requests.get("https://api.github.com/user/emails",
-                                  headers={
-                                      "Accept": "application/json",
-                                      "Authorization": f"token {oauth_data.get('access_token')}"
-                                  }).json()
-
-        organizations = requests.get("https://api.github.com/user/orgs", headers={
-            "Accept": "application/json",
-            "Authorization": f"token {oauth_data.get('access_token')}"
-        }).json()
-        temp_password = None
-        required_organizations = current_app.config.get("GITHUB_REQUIRED_ORGANIZATIONS")
-        if required_organizations:
-            logins = set([org["login"] for org in organizations])  # pylint: disable=consider-using-set-comprehension
-            required_organizations = set(required_organizations)
-            if len(logins.intersection(required_organizations)) == 0:
-                raise GithubOrganizationMissingError(
-                    "Not a member of a required organization or missing organization scope")
-
-        try:
-            user = User.get(username=user_info.get("login"))
-        except User.DoesNotExist:
-            user = User()
-            user.username = user_info.get("login")
-            user.email = email_info[-1].get("email")
-            user.full_name = user_info.get("name", user_info.get("login"))
-            user.registration_date = datetime.datetime.utcnow()
-            user.roles = ["ROLE_USER"]
-            temp_password = base64.encodebytes(
-                os.urandom(48)).decode("ascii").strip()
-            user.password = generate_password_hash(temp_password)
-
-            avatar_url: str = user_info.get("avatar_url")
-            avatar = requests.get(avatar_url).content
-            avatar_name = avatar_url.split("/")[-1]
-            filename, filepath = self.save_profile_picture_to_disk(avatar_name, avatar, user.username)
-
-            web_file = WebFileStorage()
-            web_file.filename = filename
-            web_file.filepath = filepath
-            web_file.save()
-            user.picture_id = web_file.id
-            user.save()
-
-        try:
-            tokens = list(UserOauthToken.filter(user_id=user.id).all())
-            github_token = [
-                token for token in tokens if token["kind"] == "github"][0]
-            github_token.token = oauth_data.get('access_token')
-            github_token.save()
-        except (UserOauthToken.DoesNotExist, IndexError):
-            github_token = UserOauthToken()
-            github_token.kind = "github"
-            github_token.user_id = user.id
-            github_token.token = oauth_data.get('access_token')
-            github_token.save()
-
-        session.clear()
-        session["user_id"] = str(user.id)
-        if temp_password:
-            return {
-                "password": temp_password,
-                "first_login": True
-            }
-        return None
-
     def get_jobs_for_user(self, user: User):
-        runs = self.session.execute(self.jobs_by_assignee, parameters=(user.id,))
+        runs: list[SCTTestRun] = list(SCTTestRun.filter(assignee=user.id).all())
         schedules = self.get_schedules_for_user(user)
         valid_runs = []
         today = datetime.datetime.now()
         month_ago = today - datetime.timedelta(days=30)
         for run in runs:
-            run_date = run["start_time"]
-            if user.id == run["assignee"] and run_date >= month_ago:
+            run_date = run.start_time
+            if user.id == run.assignee and run_date >= month_ago:
                 valid_runs.append(run)
                 continue
             for schedule in schedules:
-                if not run["release_id"] == schedule["release_id"]:
+                if not run.release_id == schedule["release_id"]:
                     continue
                 if not schedule["period_start"] < run_date < schedule["period_end"]:
                     continue
-                if run["assignee"] in schedule["assignees"]:
+                if run.assignee in schedule["assignees"]:
                     valid_runs.append(run)
                     break
-                if run["group_id"] in schedule["groups"]:
+                if run.group_id in schedule["groups"]:
                     valid_runs.append(run)
                     break
-                filtered_tests = [test for test in schedule["tests"] if test == run["test_id"]]
+                filtered_tests = [test for test in schedule["tests"] if test == run.test_id]
                 if len(filtered_tests) > 0:
                     valid_runs.append(run)
                     break
         return valid_runs
 
     def get_schedules_for_user(self, user: User):
-        all_assigned_schedules = ArgusReleaseScheduleAssignee.filter(assignee=user.id).all()
+        all_assigned_schedules = ArgusScheduleAssignee.filter(assignee=user.id).all()
         schedule_keys = [(schedule_assignee.release_id, schedule_assignee.schedule_id)
                          for schedule_assignee in all_assigned_schedules]
         schedules = []
         today = datetime.datetime.utcnow()
         for release_id, schedule_id in schedule_keys:
             try:
-                schedule = dict(ArgusReleaseSchedule.get(release_id=release_id, id=schedule_id).items())
-            except ArgusReleaseSchedule.DoesNotExist:
+                schedule = dict(ArgusSchedule.get(release_id=release_id, id=schedule_id).items())
+            except ArgusSchedule.DoesNotExist:
                 continue
             if schedule["period_start"] <= today <= schedule["period_end"]:
-                tests = ArgusReleaseScheduleTest.filter(schedule_id=schedule_id).all()
+                tests = ArgusScheduleTest.filter(schedule_id=schedule_id).all()
                 schedule["tests"] = [test.test_id for test in tests]
-                groups = ArgusReleaseScheduleGroup.filter(schedule_id=schedule_id).all()
+                groups = ArgusScheduleGroup.filter(schedule_id=schedule_id).all()
                 schedule["groups"] = [group.group_id for group in groups]
-                assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule_id).all()
+                assignees = ArgusScheduleAssignee.filter(schedule_id=schedule_id).all()
                 schedule["assignees"] = [assignee.assignee for assignee in assignees]
                 schedules.append(schedule)
 
@@ -1211,7 +971,7 @@ class ArgusService:
 
     def get_planner_comment_by_test(self, test_id):
         try:
-            test = ArgusReleaseGroupTest.get(id=test_id)
+            test = ArgusTest.get(id=test_id)
             return ReleasePlannerComment.get(test=test.id, release=test.release_id, group=test.group_id).comment
         except ReleasePlannerComment.DoesNotExist:
             return ""
